@@ -224,11 +224,16 @@ external_checks = {'imports': 'from collections import Counter, namedtuple, defa
                                'SimpleNamespace']}
 
 
-def argument_inspector(arg, no_of_arguments=2, p=False, print_width=120):
+def argument_inspector(arg, lib=None, no_of_arguments=2, p=False, print_width=120):
     from collections import defaultdict
     import warnings
     warnings.filterwarnings("ignore")
     rtrnd_dct = defaultdict(set)
+    if lib:
+        try:
+            exec(f'from {lib} import {arg}')
+        except:
+            pass
     if no_of_arguments >= 0:
         try:
             x = eval(f'{arg}()')
